summaryrefslogtreecommitdiffstats
path: root/source/d/p2c/p2c.getline.diff
blob: 25df12c150a88fcb4f913d6cb2a23f68c78ce112 (plain) (blame)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
--- ./src/parse.c.orig	2018-02-01 15:25:56.206878896 -0600
+++ ./src/parse.c	2018-02-01 15:28:00.997877570 -0600
@@ -5073,7 +5073,7 @@
 	out_include(fname, 1);
     outsection(majorspace);
     pop_input();
-    getline();
+    p2c_getline();
     gettok();
 }
 
--- ./src/TAGS.orig	1993-12-07 23:36:55.000000000 -0600
+++ ./src/TAGS	2018-02-01 15:27:50.927877677 -0600
@@ -176,7 +176,7 @@
 char getchartok(2466,60243
 Static int getflag(2451,60064
 char *getinlinepart(2414,59241
-void getline(1047,22000
+void p2c_getline(1047,22000
 char *getparenstr(2481,60499
 void gettok(2728,65611
 void gettok(2752,66193
--- ./src/lex.c.orig	1993-12-07 23:36:49.000000000 -0600
+++ ./src/lex.c	2018-02-01 15:27:54.224877642 -0600
@@ -1044,7 +1044,7 @@
 
 
 
-void getline()
+void p2c_getline()
 {
     char *cp, *cp2;
 
@@ -1071,7 +1071,7 @@
 			infname = stralloc(cp);
 			infname[cp2 - cp] = 0;
 		    }
-		    getline();
+		    p2c_getline();
 		    return;
 		}
 		if (copysource && *inbuf) {
@@ -1088,7 +1088,7 @@
                     fprintf(stderr, "\n");
                 if (inputkind == INP_INCFILE) {
                     pop_input();
-                    getline();
+                    p2c_getline();
                 } else
                     strcpy(inbuf, "\001");
             }
@@ -1179,7 +1179,7 @@
         infname = fname;
         inf_lnum = 0;
     } else
-        inf_lnum--;     /* adjust for extra getline() */
+        inf_lnum--;     /* adjust for extra p2c_getline() */
     *inbuf = 0;
     inbufptr = inbuf;
     gettok();
@@ -2367,7 +2367,7 @@
 		else
 		    commentline(CMT_POST);
 		trailing = 0;
-                getline();
+                p2c_getline();
 		i = 0;
 		for (;;) {
 		    if (*inbufptr == ' ') {
@@ -2419,7 +2419,7 @@
         if (isspace(*inbufptr)) {
             inbufptr++;
         } else if (!*inbufptr) {
-            getline();
+            p2c_getline();
         } else if (*inbufptr == '{') {
             inbufptr++;
             comment(0);
@@ -2513,7 +2513,7 @@
         switch (*inbufptr++) {
 
             case 0:
-                getline();
+                p2c_getline();
                 break;
 
             case ' ':
@@ -2765,7 +2765,7 @@
             case 0:
 	        if (commenting_flag)
 		    saveinputcomment(inbufptr-1);
-                getline();
+                p2c_getline();
 		cp = curtokbuf;
 		for (;;) {
 		    inbufindent = 0;
@@ -2782,7 +2782,7 @@
 		    }
 		    if (!*inbufptr && !commenting_flag) {   /* blank line */
 			*cp++ = '\001';
-			getline();
+			p2c_getline();
 		    } else
 			break;
 		}
@@ -2797,10 +2797,10 @@
 		*cp++ = '\001';
 		*cp++ = '\014';
 		if (!*inbufptr && !commenting_flag) {
-		    getline();
+		    p2c_getline();
 		    while (!*inbufptr) {
 			*cp++ = '\001';
-			getline();
+			p2c_getline();
 		    }
 		}
 		*cp = 0;